hyperspy\.utils package
=======================

Submodules
----------

hyperspy\.utils\.eds module
---------------------------

.. automodule:: hyperspy.utils.eds
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.markers module
-------------------------------

.. automodule:: hyperspy.utils.markers
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.material module
--------------------------------

.. automodule:: hyperspy.utils.material
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.model module
-----------------------------

.. automodule:: hyperspy.utils.model
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.model\_selection module
----------------------------------------

.. automodule:: hyperspy.utils.model_selection
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.parallel\_pool module
--------------------------------------

.. automodule:: hyperspy.utils.parallel_pool
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.plot module
----------------------------

.. automodule:: hyperspy.utils.plot
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.roi module
---------------------------

.. automodule:: hyperspy.utils.roi
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.utils\.samfire module
-------------------------------

.. automodule:: hyperspy.utils.samfire
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.utils
    :members:
    :undoc-members:
    :show-inheritance:
